netapp_ontap.models.kerberos_realm_kdc API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.kerberos_realm_kdc`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class KerberosRealmKdcSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the KerberosRealmKdc object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `ip: str GET POST PATCH`

    KDC IP address

    Example: 1.2.3.4

  `port: Size GET POST PATCH`

    KDC port

    Example: 88

  `vendor: str GET POST PATCH`

    Key Distribution Center (KDC) vendor. Following values are supported:

    - microsoft - Microsoft Active Directory KDC
    - other - MIT Kerberos KDC or other KDC

    Valid choices:

    - microsoft
    - other